@@ -1,38 +1,15 @@
-struct CryptKeyCacheItem
-{
-  CryptKeyCacheItem()
-  {
-    Password.Set(L"");
-  }
-
-  ~CryptKeyCacheItem()
-  {
-    cleandata(AESKey,sizeof(AESKey));
-    cleandata(AESInit,sizeof(AESInit));
-    cleandata(&Password,sizeof(Password));
-  }
-
-  byte AESKey[16],AESInit[16];
-  SecPassword Password;
-  bool SaltPresent;
-  byte Salt[SIZE_SALT30];
-};
-
-static CryptKeyCacheItem Cache[4];
-static int CachePos=0;
-
 void CryptData::SetKey30(bool Encrypt,SecPassword *Password,const wchar *PwdW,const byte *Salt)
 {
   byte AESKey[16],AESInit[16];
 
   bool Cached=false;
-  for (uint I=0;I<ASIZE(Cache);I++)
-    if (Cache[I].Password==*Password &&
-        (Salt==NULL && !Cache[I].SaltPresent || Salt!=NULL &&
-        Cache[I].SaltPresent && memcmp(Cache[I].Salt,Salt,SIZE_SALT30)==0))
+  for (uint I=0;I<ASIZE(KDF3Cache);I++)
+    if (KDF3Cache[I].Pwd==*Password &&
+        (Salt==NULL && !KDF3Cache[I].SaltPresent || Salt!=NULL &&
+        KDF3Cache[I].SaltPresent && memcmp(KDF3Cache[I].Salt,Salt,SIZE_SALT30)==0))
     {
-      memcpy(AESKey,Cache[I].AESKey,sizeof(AESKey));
-      memcpy(AESInit,Cache[I].AESInit,sizeof(AESInit));
+      memcpy(AESKey,KDF3Cache[I].Key,sizeof(AESKey));
+      memcpy(AESInit,KDF3Cache[I].Init,sizeof(AESInit));
       Cached=true;
       break;
     }
@@ -73,12 +50,12 @@ void CryptData::SetKey30(bool Encrypt,SecPassword *Password,const wchar *PwdW,co
       for (int J=0;J<4;J++)
         AESKey[I*4+J]=(byte)(digest[I]>>(J*8));
 
-    Cache[CachePos].Password=*Password;
-    if ((Cache[CachePos].SaltPresent=(Salt!=NULL))==true)
-      memcpy(Cache[CachePos].Salt,Salt,SIZE_SALT30);
-    memcpy(Cache[CachePos].AESKey,AESKey,sizeof(AESKey));
-    memcpy(Cache[CachePos].AESInit,AESInit,sizeof(AESInit));
-    CachePos=(CachePos+1)%ASIZE(Cache);
+    KDF3Cache[KDF3CachePos].Pwd=*Password;
+    if ((KDF3Cache[KDF3CachePos].SaltPresent=(Salt!=NULL))==true)
+      memcpy(KDF3Cache[KDF3CachePos].Salt,Salt,SIZE_SALT30);
+    memcpy(KDF3Cache[KDF3CachePos].Key,AESKey,sizeof(AESKey));
+    memcpy(KDF3Cache[KDF3CachePos].Init,AESInit,sizeof(AESInit));
+    KDF3CachePos=(KDF3CachePos+1)%ASIZE(KDF3Cache);
 
     cleandata(RawPsw,sizeof(RawPsw));
   }
